==> mastercard_mdes_customer_service-0.0.1.tar.gz: mastercard_mdes_customer_service-0.0.1/tests/test_tokenupdate.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

import unittest
from mastercardapicore import RequestMap, Config, OAuthAuthentication
from os.path import dirname, realpath, join
from mastercardmdescustomerservice import TokenUpdate


class TokenUpdateTest(unittest.TestCase):

    def setUp(self):
        keyFile = join(dirname(realpath(__file__)),"resources","mcapi_sandbox_key.p12")
        auth = OAuthAuthentication("L5BsiPgaF-O3qA36znUATgQXwJB6MRoMSdhjd7wt50c97279!50596e52466e3966546d434b7354584c4975693238513d3d",keyFile, "alias", "password")
        Config.setAuthentication(auth)
        Config.setDebug(True)

    
        
                
    def test_example_mdes_token_update_pan_exp_token_unique_ref(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.TokenUniqueReference", "DWSPMC00000000010906a349d9ca4eb1a4d53e3c90a11d9c")
        mapObj.set("TokenUpdateRequest.NewAccountPan", "5412345678908888")
        mapObj.set("TokenUpdateRequest.ExpirationDate", "0519")
        mapObj.set("TokenUpdateRequest.AccountPanSequenceNumber", "1")
        mapObj.set("TokenUpdateRequest.UpdateWalletProviderIndicator", "1")
        mapObj.set("TokenUpdateRequest.CommentText", "Confirmed cardholder identity.")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "5555551234")
        
        response = TokenUpdate.create(mapObj)
        self.customAssertValue("DWSPMC00000000010906a349d9ca4eb1a4d53e3c90a11d9c", response.get("TokenUpdateResponse.Tokens.Token.TokenUniqueReference"))
        self.customAssertValue("2345", response.get("TokenUpdateResponse.Tokens.Token.CommentId"))
        
    
    def test_example_mdes_token_update_pan_exp_current_pan(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.CurrentAccountPan", "1234567890123456")
        mapObj.set("TokenUpdateRequest.NewAccountPan", "5412345678908888")
        mapObj.set("TokenUpdateRequest.ExpirationDate", "1219")
        mapObj.set("TokenUpdateRequest.AccountPanSequenceNumber", "1")
        mapObj.set("TokenUpdateRequest.CommentText", "Cardholder has a new Account Pan.")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "555 1234")
        
        response = TokenUpdate.create(mapObj)
        
    
    def test_example_mdes_token_update_issuer_prod_config_single_token_by_token_unique_ref(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.TokenUniqueReference", "DWSPMC00000000010906a349d9ca4eb1a4d53e3c90a11d9c")
        mapObj.set("TokenUpdateRequest.IssuerProductConfigurationId", "ANYGOLD101")
        mapObj.set("TokenUpdateRequest.CommentText", "Update gold artwork")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "555 1234")
        
        response = TokenUpdate.create(mapObj)
        
    
    def test_example_mdes_token_update_issuer_prod_config_token_by_pan(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.CurrentAccountPan", "1234567890123456")
        mapObj.set("TokenUpdateRequest.IssuerProductConfigurationId", "ANYGOLD101")
        mapObj.set("TokenUpdateRequest.CommentText", "Update gold artwork")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "555 1234")
        
        response = TokenUpdate.create(mapObj)
        
    
        
        
        
        
        
        
    

    def customAssertValue(self,expected,actual):
        if (isinstance(actual,float)):
            self.assertEqual(float(expected), actual)
        else:
            self.assertEqual(expected.lower(), str(actual).lower())


if __name__ == '__main__':
    unittest.main()

==> mastercard_mdes_customer_service-1.0.0.tar.gz: mastercard_mdes_customer_service-1.0.0/tests/test_tokenupdate.py <==
#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#

import unittest
from mastercardapicore import RequestMap, Config, OAuthAuthentication
from os.path import dirname, realpath, join
from mastercardmdescustomerservice import *


class TokenUpdateTest(unittest.TestCase):

    def setUp(self):
        keyFile = join(dirname(realpath(__file__)),"resources","mcapi_sandbox_key.p12")
        auth = OAuthAuthentication("L5BsiPgaF-O3qA36znUATgQXwJB6MRoMSdhjd7wt50c97279!50596e52466e3966546d434b7354584c4975693238513d3d",keyFile, "alias", "password")
        Config.setAuthentication(auth)
        Config.setDebug(True)

    
        
                
    def test_example_mdes_token_update_pan_exp_token_unique_ref(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.TokenUniqueReference", "DWSPMC00000000010906a349d9ca4eb1a4d53e3c90a11d9c")
        mapObj.set("TokenUpdateRequest.NewAccountPan", "5412345678908888")
        mapObj.set("TokenUpdateRequest.ExpirationDate", "0519")
        mapObj.set("TokenUpdateRequest.AccountPanSequenceNumber", "1")
        mapObj.set("TokenUpdateRequest.UpdateWalletProviderIndicator", "1")
        mapObj.set("TokenUpdateRequest.CommentText", "Confirmed cardholder identity.")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "5555551234")
        
        response = TokenUpdate.create(mapObj)
        self.customAssertValue("DWSPMC00000000010906a349d9ca4eb1a4d53e3c90a11d9c", response.get("TokenUpdateResponse.Tokens.Token.TokenUniqueReference"))
        self.customAssertValue("2345", response.get("TokenUpdateResponse.Tokens.Token.CommentId"))
        
    
    def test_example_mdes_token_update_pan_exp_current_pan(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.CurrentAccountPan", "1234567890123456")
        mapObj.set("TokenUpdateRequest.NewAccountPan", "5412345678908888")
        mapObj.set("TokenUpdateRequest.ExpirationDate", "1219")
        mapObj.set("TokenUpdateRequest.AccountPanSequenceNumber", "1")
        mapObj.set("TokenUpdateRequest.CommentText", "Cardholder has a new Account Pan.")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "555 1234")
        
        response = TokenUpdate.create(mapObj)
        
    
    def test_example_mdes_token_update_issuer_prod_config_single_token_by_token_unique_ref(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.TokenUniqueReference", "DWSPMC00000000010906a349d9ca4eb1a4d53e3c90a11d9c")
        mapObj.set("TokenUpdateRequest.IssuerProductConfigurationId", "ANYGOLD101")
        mapObj.set("TokenUpdateRequest.CommentText", "Update gold artwork")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "555 1234")
        
        response = TokenUpdate.create(mapObj)
        
    
    def test_example_mdes_token_update_issuer_prod_config_token_by_pan(self):
        mapObj = RequestMap()
        mapObj.set("TokenUpdateRequest.CurrentAccountPan", "1234567890123456")
        mapObj.set("TokenUpdateRequest.IssuerProductConfigurationId", "ANYGOLD101")
        mapObj.set("TokenUpdateRequest.CommentText", "Update gold artwork")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserId", "A1435477")
        mapObj.set("TokenUpdateRequest.AuditInfo.UserName", "John Smith")
        mapObj.set("TokenUpdateRequest.AuditInfo.Organization", "Any Bank")
        mapObj.set("TokenUpdateRequest.AuditInfo.Phone", "555 1234")
        
        response = TokenUpdate.create(mapObj)
        
    
        
        
        
        
        
        
    

    def customAssertValue(self,expected,actual):
        if (isinstance(actual,float)):
            self.assertEqual(float(expected), actual)
        else:
            self.assertEqual(expected.lower(), str(actual).lower())


if __name__ == '__main__':
    unittest.main()
